@@ -16,7 +16,6 @@ class NbController(HTTPMethodView):
     async def get(self, request, token):
         uid = str(uuid.uuid4())
         task = await self.__jobs.find_by_value(uid, token, t_notebook)
-        print("task", task)
         if task:
             value = task.get("value", None)
             file_filepath = task.get("path")
@@ -77,7 +76,9 @@ class NbController(HTTPMethodView):
                 t_health,
                 res.get("duration"),
             )
-            return self.__nb.response(uid, res, res.get("duration"), task.get("params"))
+            return self.__nb.response(
+                uid, file_filepath, res, res.get("duration"), task.get("params")
+            )
         self.__logger.error(
             {
                 "id": uid,
