@@ -17,9 +17,11 @@ import errno
 import json
 import os
 import uuid
+from sanic.exceptions import ServerError
 
 
 filters = [t_notebook, t_asset, t_dependency, t_scheduler]
+filters_api = [t_notebook, t_asset]
 
 
 class Jobs:
@@ -83,6 +85,7 @@ class Jobs:
                     "params",
                     "lastUpdate",
                     "lastRun",
+                    "nbRun",
                     "totalRun",
                 ]
             )
@@ -90,6 +93,18 @@ class Jobs:
     def __cleanup_jobs(self):
         if len(self.__df) > 0:
             self.__df = self.__df[self.__df.type.isin(filters)]
+            self.__dedup_jobs()
+
+    def __dedup_jobs(self):
+        new_df = self.__df[
+            (self.__df.type != t_notebook) & (self.__df.type != t_asset)
+        ].to_dict("records")
+        cur_notebook = self.__df[self.__df.type == t_notebook]
+        cur_asset = self.__df[self.__df.type == t_asset]
+        cur_asset = cur_asset.drop_duplicates(subset=["value"]).to_dict("records")
+        cur_notebook = cur_notebook.drop_duplicates(subset=["value"]).to_dict("records")
+        self.__df = pd.DataFrame([*new_df, *cur_asset, *cur_notebook])
+        self.__df = self.__df.reset_index(drop=True)
 
     def __get_save_from_file(self, uid):
         data = []
@@ -107,7 +122,7 @@ class Jobs:
                     "error": str(err),
                 }
             )
-        return pd.DataFrame(data)
+        return pd.DataFrame(data).reset_index(drop=True)
 
     def __save_to_file(self, uid, data):
         try:
@@ -137,7 +152,7 @@ class Jobs:
                         (self.__df.type == target_type) & (self.__df.value == value)
                     ]
                     cur_job = cur_jobs.to_dict("records")
-                    if len(cur_job) == 1:
+                    if len(cur_job) > 0:
                         res = cur_job[0]
             except Exception as e:
                 print("find_by_value", e)
@@ -152,7 +167,7 @@ class Jobs:
                         (self.__df.type == target_type) & (self.__df.path == filepath)
                     ]
                     cur_job = cur_jobs.to_dict("records")
-                    if len(cur_job) == 1:
+                    if len(cur_job) > 0:
                         res = cur_job[0]
             except Exception as e:
                 print("find_by_path", e)
@@ -174,7 +189,6 @@ class Jobs:
         data = []
         try:
             async with self.__storage_sem:
-                print("list acquire", uid)
                 data = self.__df.to_dict("records")
         except Exception as e:
             print("list", e)
@@ -186,11 +200,32 @@ class Jobs:
         async with self.__storage_sem:
             try:
                 res = status
+                now = datetime.datetime.now()
+                dt_string = now.strftime("%Y-%m-%d %H:%M:%S")
                 cur_elem = self.__df[
                     (self.__df.type == target_type) & (self.__df.path == path)
                 ]
-                now = datetime.datetime.now()
-                dt_string = now.strftime("%Y-%m-%d %H:%M:%S")
+                dup_elem = self.__df[
+                    (self.__df.path != path)
+                    & (self.__df.type == target_type)
+                    & (self.__df.value == value)
+                ]
+                if len(dup_elem) > 0 and target_type in filters_api:
+                    self.__logger.error(
+                        {
+                            "id": uid,
+                            "type": target_type,
+                            "value": value,
+                            "status": t_error,
+                            "path": path,
+                            "params": params,
+                            "error": "Already exist",
+                        }
+                    )
+                    return {
+                        "id": uid,
+                        "error": f"type {target_type} with key {value} already exist",
+                    }
                 if len(cur_elem) == 1:
                     if status == t_delete:
                         self.__logger.info(
@@ -222,16 +257,18 @@ class Jobs:
                         self.__df.at[index, "params"] = params
                         self.__df.at[index, "lastUpdate"] = dt_string
                         if runTime > 0 and status != t_add:
-                            self.__df.at[index, "lastRun"] = runTime
-                            self.__df.at[index, "totalRun"] = runTime + (
-                                self.__df.at[index, "totalRun"]
-                                if self.__df.at[index, "totalRun"]
-                                else 0
+                            self.__df.at[index, "nbRun"] = (
+                                self.__df.at[index, "nbRun"] + 1
                             )
+                            self.__df.at[index, "lastRun"] = runTime
+                            totalRun = float(self.__df.at[index, "totalRun"])
+                            self.__df.at[index, "totalRun"] = runTime + totalRun
+                            res = t_update
                         elif status == t_add:
+                            self.__df.at[index, "nbRun"] = 0
                             self.__df.at[index, "lastRun"] = 0
                             self.__df.at[index, "totalRun"] = 0
-                        res = t_update
+                            res = t_add
                 elif status == t_add and len(cur_elem) == 0:
                     self.__logger.info(
                         {
@@ -251,13 +288,17 @@ class Jobs:
                             "status": t_add,
                             "path": path,
                             "params": params,
+                            "nbRun": 1 if runTime > 0 else 0,
                             "lastRun": runTime,
                             "totalRun": runTime,
                             "lastUpdate": dt_string,
                         }
                     ]
-                    df_new = pd.DataFrame(new_row)
-                    self.__df = pd.concat([self.__df, df_new], axis=0)
+                    cur_df = self.__df.to_dict("records")
+                    if len(self.__df) > 0:
+                        self.__df = pd.DataFrame([*cur_df, *new_row])
+                    else:
+                        self.__df = pd.DataFrame(new_row)
                 else:
                     res = t_skip
             except Exception as e:
@@ -273,7 +314,7 @@ class Jobs:
                         "error": str(e),
                     }
                 )
+                raise ServerError({"id": uid, "error": str(e)}, status_code=500)
             data = self.__df.to_dict("records")
             self.__save_to_file(uid, data)
-            print("release =>\n\n")
         return {"status": res, "data": data}
