@@ -53,8 +53,9 @@ class Notifications:
             return jsn
         content = ""
         if current_type == t_asset or current_type == t_notebook:
-            content = f"The file {file_path} accesible at this url:\n {encode_proxy_url(current_type)}/{current_value}\n is {status}.\n\n"
-            content = content + "Check the Logs on your manager below :\n"
+            content = f"The file {file_path} accesible at this url:<br/> {encode_proxy_url(current_type)}/{current_value}<br/>"
+            content = content + f"is {status}.<br/><br/>"
+            content = content + "Check the Logs on your manager below :<br/>"
         elif current_type == t_scheduler:
             cron_string = pretty_cron.prettify_cron(current_value)
             content = f"Your {file_path} who run {cron_string} is {status}, check the Logs on your manager below :"
@@ -67,12 +68,11 @@ class Notifications:
         logo_url = f"{encode_proxy_url('manager')}/asset/naas_logo"
         try:
             data = {
+                "title": "Naas manager notification",
                 "subject": f"{current_type.capitalize()} {status}",
                 "email": email,
-                "title": "Naas manager notification",
                 "content": content,
-                "image": status_url,
-                "vars": {
+                "custom_vars": {
                     "URL_HOME": encode_proxy_url("manager"),
                     "URL_LOGO": logo_url,
                     "ALT_LOGO": "Naas Manager LOGO",
